#!/usr/bin/env python
# -*- coding: utf-8 -*-
from gimpfu import *

############################################################################
# include, then use: erro_msg or info_msg
#---------------------------------------------------------------------------
def erro_msg (msg):
    ###
    currenth = pdb.gimp_message_get_handler()
    pdb.gimp_message_set_handler(0) # box
    gimp.message ("ERROR: "+msg)
    pdb.gimp_message_set_handler(currenth) # current
    ###
def info_msg (msg):
    ###
    currenth = pdb.gimp_message_get_handler()
    pdb.gimp_message_set_handler(2) # error console
    gimp.message ("INFO: "+msg)
    pdb.gimp_message_set_handler(currenth) # current
    ###
############################################################################
#
# 
# definition of the script
# name must correspond to the name
# at the bottom of the registration, before menu
#

def EnhanceSkins(inImage, inDrawable, inOpacity) :

    if pdb.gimp_selection_is_empty(inImage):
      erro_msg("Please select skin area")
      return()
    
    # Store the GIMP's settings so they can be restored when we're finished
    gimp.context_push()

    # Make all the operations in this filter undo in one group
    inImage.undo_group_start()

    ow=pdb.gimp_image_width(inImage)
    oh=pdb.gimp_image_height(inImage)
    fw=ow/100
    fh=oh/100

    copiedDrawable=pdb.gimp_layer_copy(inDrawable, True)
    pdb.gimp_image_add_layer(inImage, copiedDrawable, -1)
    pdb.gimp_layer_add_alpha(copiedDrawable)
    pdb.gimp_image_set_active_layer(inImage, copiedDrawable)

    pdb.gimp_context_set_antialias(True)
    pdb.gimp_context_set_feather(True)
    pdb.gimp_context_set_feather_radius(fw, fh)
    pdb.gimp_context_set_sample_criterion(0)
    pdb.gimp_context_set_sample_merged(FALSE)
    pdb.gimp_context_set_sample_threshold(0.25)   

    (meanV, std_devV, medianV, pixelsV, countV, percentileV) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_VALUE,0,255)
    (meanR, std_devR, medianR, pixelsR, countR, percentileR) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_RED,0,255)
    (meanG, std_devG, medianG, pixelsG, countG, percentileG) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_GREEN,0,255)
    (meanB, std_devB, medianB, pixelsB, countB, percentileB) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_BLUE,0,255)

    pdb.gimp_image_select_color(inImage, CHANNEL_OP_INTERSECT, copiedDrawable, (int(meanR)/2*3, int(meanG)/2*3, int(meanB)/2*3))
    pdb.gimp_selection_grow(inImage, fw)
    pdb.plug_in_sel_gauss(inImage, copiedDrawable, 5, 50)

    (meanV, std_devV, medianV, pixelsV, countV, percentileV) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_VALUE,0,255)
    (meanR, std_devR, medianR, pixelsR, countR, percentileR) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_RED,0,255)
    (meanG, std_devG, medianG, pixelsG, countG, percentileG) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_GREEN,0,255)
    (meanB, std_devB, medianB, pixelsB, countB, percentileB) = pdb.gimp_histogram (copiedDrawable, HISTOGRAM_BLUE,0,255)
    
    pdb.gimp_hue_saturation(copiedDrawable, RED_HUES,  0, 0, 50)
    pdb.gimp_hue_saturation(copiedDrawable, YELLOW_HUES,  0, 0, 50)
    pdb.gimp_hue_saturation(copiedDrawable, MAGENTA_HUES,  0, 0, 50)

    pdb.gimp_layer_set_mode(copiedDrawable, NORMAL_MODE)
    pdb.gimp_layer_set_opacity(copiedDrawable, inOpacity)
    
    pdb.gimp_selection_none(inImage)
    
    inImage.undo_group_end()
    gimp.context_pop()

    return

# This is the plugin registration function
register(
    "EnhanceSkins",    
    "to enhance skin colors (selecion of skin area reqd)",   
    "This script makes skins more denoised and saturated (selection reqd)",
    "Diego", 
    "Diego Nassetti ", 
    "June 2017",
    "EnhanceSkins", 
    "*", 
    [
      (PF_IMAGE, "image", "Input image", None),
      (PF_DRAWABLE, "drawable", "Input drawable", None),
      (PF_SLIDER, 'opacity', 'opacity level:', 50, (10, 100, 10))
    ], 
    [],
    EnhanceSkins,
    menu="<Image>/Diego/Ancillary/",
    )

main()
